@@ -5,7 +5,6 @@
 # Please see the file LICENSE.txt for details.
 #
 import numpy as np
-import warnings
 
 from ginga import trcalc
 from ginga.misc import Bunch
@@ -311,6 +310,18 @@ class AutoCutsBase(object):
 
 
 class Clip(AutoCutsBase):
+    """Calculate the cut levels as the minimum and maximum of the data.
+
+    The calculation is:
+        loval = min(sample_data)
+        hival = max(sample_data)
+
+    Parameters
+    ----------
+    logger : :py:class:`~logging.Logger`
+        Logger for tracing and debugging.
+
+    """
 
     def __init__(self, logger):
         super(Clip, self).__init__(logger)
@@ -434,11 +445,6 @@ class Histogram(AutoCutsBase):
         self.pct = pct
         self.numbins = numbins
 
-        if usecrop is not None:
-            warnings.warn("The usecrop parameter has been deprecated--"
-                          "use sample=crop inst",
-                          PendingDeprecationWarning)
-
     def calc_cut_levels(self, image):
         """See subclass documentation."""
         if self.sample == 'crop':
@@ -624,11 +630,6 @@ class StdDev(AutoCutsBase):
         self.hensa_lo = hensa_lo
         self.hensa_hi = hensa_hi
 
-        if usecrop is not None:
-            warnings.warn("The usecrop parameter has been deprecated--"
-                          "use sample=crop instead",
-                          PendingDeprecationWarning)
-
     def calc_cut_levels(self, image):
         """See subclass documentation."""
         if self.sample == 'crop':
