@@ -4,14 +4,11 @@
 # This is open-source software licensed under a BSD license.
 # Please see the file LICENSE.txt for details.
 #
-import sys
-import traceback
 from functools import reduce
+import warnings
 
 import numpy as np
 
-from ginga.canvas import coordmap
-
 __all__ = ['CompoundMixin']
 
 
@@ -51,10 +48,6 @@ class CompoundMixin(object):
         x2, y2 = t_[2].max(), t_[3].max()
         return (x1, y1, x2, y2)
 
-    def get_edit_points(self, viewer):
-        x1, y1, x2, y2 = self.get_llur()
-        return [(x1, y1), (x2, y1), (x2, y2), (x1, y2)]
-
     def contains_pts(self, pts):
         if len(self.objects) == 0:
             x_arr, y_arr = np.asarray(pts).T
@@ -102,35 +95,17 @@ class CompoundMixin(object):
                     # custom test
                     res.append(obj)
         except Exception as e:
-            #print("error selecting objects: %s" % (str(e)))
-            try:
-                # log traceback, if possible
-                (type, value, tb) = sys.exc_info()
-                tb_str = "".join(traceback.format_tb(tb))
-                self.logger.error("Traceback:\n%s" % (tb_str))
-            except Exception:
-                tb_str = "Traceback information unavailable."
-                self.logger.error(tb_str)
+            self.logger.error("error selecting object(s): {}".format(e),
+                              exc_info=True)
             res = []
         return res
 
     def initialize(self, canvas, viewer, logger):
-        # TODO: this needs to be merged with the code in CanvasObject
-        self.viewer = viewer
-        self.logger = logger
-        if self.crdmap is None:
-            if self.coord == 'offset':
-                self.crdmap = coordmap.OffsetMapper(viewer, self.ref_obj)
-            else:
-                try:
-                    self.crdmap = viewer.get_coordmap(self.coord)
-                except Exception as e:
-                    # last best effort--a generic data mapper
-                    self.crdmap = coordmap.DataMapper(viewer)
+        super().initialize(canvas, viewer, logger)
 
         # initialize children
         for obj in self.objects:
-            obj.initialize(canvas, viewer, logger)
+            obj.initialize(self, viewer, logger)
 
     def inherit_from(self, obj):
         self.crdmap = obj.crdmap
@@ -141,6 +116,8 @@ class CompoundMixin(object):
         return True
 
     def use_coordmap(self, mapobj):
+        super().use_coordmap(mapobj)
+
         for obj in self.objects:
             obj.use_coordmap(mapobj)
 
@@ -155,7 +132,7 @@ class CompoundMixin(object):
         return obj in self.objects
 
     def copy(self, share=[]):
-        obj = super(CompoundMixin, self).copy(share=share)
+        obj = super().copy(share=share)
         obj.objects = [obj.copy(share=share) for obj in self.objects]
         return obj
 
@@ -223,8 +200,14 @@ class CompoundMixin(object):
             self.objects.insert(index, obj)
 
     def rotate(self, theta, xoff=0, yoff=0):
+        warnings.warn("rotate(theta_deg) has been deprecated--"
+                      "use rotate_deg([theta_deg]) instead",
+                      DeprecationWarning)
+        self.rotate_deg([theta], (xoff, yoff))
+
+    def rotate_deg(self, thetas, offset):
         for obj in self.objects:
-            obj.rotate(theta, xoff=xoff, yoff=yoff)
+            obj.rotate_deg(thetas, offset)
 
     def move_delta_pt(self, off_pt):
         for obj in self.objects:
@@ -251,16 +234,19 @@ class CompoundMixin(object):
             res.extend(list(obj.get_points()))
         return res
 
-    ### NON-PEP8 EQUIVALENTS -- TO BE DEPRECATED ###
+    def setup_edit(self, detail):
+        detail.center_pos = self.get_center_pt()
 
-    getItemsAt = get_items_at
-    getObjects = get_objects
-    deleteObject = delete_object
-    deleteObjects = delete_objects
-    deleteAllObjects = delete_all_objects
-    setAttrAll = set_attr_all
-    addObject = add_object
-    raiseObject = raise_object
-    lowerObject = lower_object
+    def get_edit_points(self, viewer):
+        move_pt, scale_pt, rotate_pt = self.get_move_scale_rotate_pts(viewer)
+        # currently only move_pt is supported for compound objects
+        return [move_pt]
 
-# END
+    def set_edit_point(self, i, pt, detail):
+        if i == 0:
+            # move control point
+            ctr_x, ctr_y = self.get_reference_pt()
+            delta_pt = (pt[0] - ctr_x, pt[1] - ctr_y)
+            self.move_delta_pt(delta_pt)
+        else:
+            raise ValueError("No point corresponding to index %d" % (i))
