@@ -5,12 +5,17 @@ import zipfile
 import urllib
 
 from astropy.utils import minversion
-from astropy.utils.data import _find_pkg_data_path
 
 from ginga import toolkit
+from ginga.util.toolbox import ASTROPY_LT_4_3
 
 __all__ = ['get_doc']
 
+if ASTROPY_LT_4_3:
+    from astropy.utils.data import _find_pkg_data_path as get_pkg_data_path
+else:
+    from astropy.utils.data import get_pkg_data_path
+
 
 def _find_rtd_version():
     """Find closest RTD doc version."""
@@ -27,7 +32,7 @@ def _find_rtd_version():
 
     # Get RTD download listing.
     url = 'https://readthedocs.org/projects/ginga/downloads/'
-    with urllib.request.urlopen(url) as r:
+    with urllib.request.urlopen(url) as r:  # nosec
         soup = BeautifulSoup(r, 'html.parser')
 
     # Compile a list of available HTML doc versions for download.
@@ -81,7 +86,7 @@ def _download_rtd_zip(rtd_version=None, **kwargs):
         rtd_version = _find_rtd_version()
 
     data_path = os.path.dirname(
-        _find_pkg_data_path('help.html', package='ginga.doc'))
+        get_pkg_data_path('help.html', package='ginga.doc'))
     index_html = os.path.join(data_path, 'index.html')
 
     # There is a previous download of documentation; Do nothing.
@@ -92,7 +97,7 @@ def _download_rtd_zip(rtd_version=None, **kwargs):
 
     url = ('https://readthedocs.org/projects/ginga/downloads/htmlzip/'
            '{}/'.format(rtd_version))
-    local_path = urllib.request.urlretrieve(url, **kwargs)[0]
+    local_path = urllib.request.urlretrieve(url, **kwargs)[0]  # nosec
 
     with zipfile.ZipFile(local_path, 'r') as zf:
         zf.extractall(data_path)
