@@ -48,6 +48,10 @@ try:
     from qtpy.QtWidgets import QOpenGLWidget  # noqa
     from qtpy.QtCore import QItemSelectionModel  # noqa
     from qtpy.QtWidgets import QApplication  # noqa
+    ## try:
+    ##     from qtpy import sip
+    ## except ImportError as e:
+    ##     import sip
     try:
         from qtpy.QtWebEngineWidgets import QWebEngineView as QWebView  # noqa
     except ImportError as e:
@@ -483,4 +487,10 @@ def set_default_opengl_context():
     fmt.setDefaultFormat(fmt)
     QtCore.QCoreApplication.setAttribute(QtCore.Qt.AA_ShareOpenGLContexts)
 
+
+def delete_widget(w):
+    ## sip.delete(w)
+    w.deleteLater()
+
+
 # END
