@@ -13,7 +13,7 @@ from ginga.qtw.QtHelp import (QtGui, QtCore, QTextCursor, QIcon, QPixmap,
 from ginga.qtw import QtHelp
 
 from ginga.misc import Callback, Bunch, Settings, LineHistory
-import ginga.icons
+from ginga.util.paths import icondir
 
 has_webkit = False
 try:
@@ -34,9 +34,6 @@ __all__ = ['WidgetError', 'WidgetBase', 'TextEntry', 'TextEntrySet',
            'name_mangle', 'make_widget', 'hadjust', 'build_info', 'wrap',
            'has_webkit']
 
-# path to our icons
-icondir = os.path.split(ginga.icons.__file__)[0]
-
 
 class WidgetError(Exception):
     """For errors thrown in this module."""
@@ -81,8 +78,9 @@ class WidgetBase(Callback.Callbacks):
         return _app
 
     def delete(self):
-        self.widget.deleteLater()
-        self.widget = None
+        w, self.widget = self.widget, None
+        QtHelp.delete_widget(w)
+        #w.deleteLater()
 
     def focus(self):
         self.widget.activateWindow()
@@ -390,7 +388,7 @@ class ComboBox(WidgetBase):
 
         self.enable_callback('activated')
 
-    def _cb_redirect(self):
+    def _cb_redirect(self, *args):
         idx = self.widget.currentIndex()
         self.make_callback('activated', idx)
 
@@ -1899,8 +1897,9 @@ class MDIWindow(TopLevelMixin, WidgetBase):
         WidgetBase.__init__(self)
         self.parent = parent
         w = QtGui.QMdiSubWindow(parent.get_widget())
-        # remove Qt logo from subwindow
-        w.setWindowIcon(QIcon(QPixmap(1, 1)))
+        # replace Qt logo from subwindow
+        ginga_icon = os.path.join(icondir, "ginga.svg")
+        w.setWindowIcon(QIcon(ginga_icon))
         self.widget = w
 
         child_w = child.get_widget()
@@ -1978,6 +1977,8 @@ class TopLevel(TopLevelMixin, ContainerBase):
         ContainerBase.__init__(self)
 
         widget = QtHelp.TopLevel()
+        ginga_icon = os.path.join(icondir, "ginga.svg")
+        widget.setWindowIcon(QIcon(ginga_icon))
         self.widget = widget
         box = QtGui.QVBoxLayout()
         box.setContentsMargins(0, 0, 0, 0)
