@@ -15,18 +15,12 @@ import logging.handlers
 import threading
 import traceback
 
-if sys.version_info < (3, 8):
-    # Python 3.7
-    from importlib_metadata import entry_points
-else:
-    from importlib.metadata import entry_points
-
 # Local application imports
 from ginga.misc.Bunch import Bunch
 from ginga.misc import Task, ModuleManager, Settings, log
 import ginga.version as version
 import ginga.toolkit as ginga_toolkit
-from ginga.util import paths, rgb_cms, json
+from ginga.util import paths, rgb_cms, json, compat
 
 # Catch warnings
 logging.captureWarnings(True)
@@ -140,14 +134,19 @@ plugins = [
     Bunch(module='ColorMapPicker', tab='ColorMapPicker',
           menu="Set Color Map [G]", workspace='right', start=False,
           category='RGB', ptype='global'),
+    Bunch(module='ColorMapPicker',
+          menu="Set Color Map", workspace='dialogs', category='RGB',
+          ptype='local'),
     Bunch(module='PlotTable', workspace='dialogs', category='Table',
           ptype='local'),
     Bunch(module='Catalogs', workspace='dialogs', category='Utils',
           ptype='local'),
     Bunch(module='Drawing', workspace='dialogs', category='Utils',
           ptype='local'),
-    ## Bunch(module='Pipeline', workspace='dialogs', category='Utils',
-    ##       ptype='local'),
+    Bunch(module='AutoLoad', workspace='dialogs', category='Utils',
+          ptype='local'),
+    #Bunch(module='Pipeline', workspace='dialogs', category='Utils',
+    #      ptype='local'),
     Bunch(module='FBrowser', workspace='dialogs', category='Utils',
           ptype='local'),
     Bunch(module='ChangeHistory', tab='History', workspace='right',
@@ -209,7 +208,7 @@ class ReferenceViewer(object):
         available_methods = []
 
         for group in groups:
-            discovered_plugins = entry_points().get(group, [])
+            discovered_plugins = compat.ep_get(group)
             for entry_point in discovered_plugins:
                 try:
                     method = entry_point.load()
@@ -272,9 +271,6 @@ class ReferenceViewer(object):
         add_argument("--numthreads", dest="numthreads", type=int,
                      default=30, metavar="NUM",
                      help="Start NUM threads in thread pool")
-        add_argument("--opencv", dest="opencv", default=False,
-                     action="store_true",
-                     help="Use OpenCv acceleration")
         add_argument("--opengl", dest="opengl", default=False,
                      action="store_true",
                      help="Use OpenGL acceleration")
@@ -444,7 +440,8 @@ class ReferenceViewer(object):
             warnings.simplefilter('ignore', fits.verify.VerifyWarning)
 
         try:
-            from ginga.util import io_fits, loader
+            from ginga.util.io import io_fits
+            from ginga.util import loader
             if fitspkg != 'choose':
                 assert io_fits.use(fitspkg) is True
                 # opener name is not necessarily the same
@@ -456,14 +453,6 @@ class ReferenceViewer(object):
             logger.warning(
                 "failed to set FITS package preference '{}': {}".format(fitspkg, e))
 
-        # Check whether user specified deprecated --opencv option
-        if options.opencv:
-            logger.warning("--opencv switch is deprecated; "
-                           "OpenCv will be used by default if installed")
-
-        if options.opengl:
-            settings.set(use_opengl=True)
-
         # Create the dynamic module manager
         mm = ModuleManager.ModuleManager(logger)
 
@@ -477,6 +466,9 @@ class ReferenceViewer(object):
         ginga_shell = GingaShell(logger, thread_pool, mm, prefs,
                                  ev_quit=ev_quit)
 
+        if options.opengl:
+            settings.set(use_opengl=True)
+
         layout_file = os.path.join(basedir, settings.get('layout_file',
                                                          'layout'))
         ginga_shell.set_layout(self.layout, layout_file=layout_file,
@@ -712,32 +704,6 @@ class ReferenceViewer(object):
 
         sys.exit(0)
 
-    # TO BE DEPRECATED-- DO NOT USE!!!
-
-    def add_global_plugin_spec(self, spec):
-        if 'ptype' not in spec:
-            spec['ptype'] = 'global'
-        self.plugins.append(spec)
-
-    def add_local_plugin_spec(self, spec):
-        if 'ptype' not in spec:
-            spec['ptype'] = 'local'
-        self.plugins.append(spec)
-
-    def add_local_plugin(self, module_name, ws_name,
-                         path=None, klass=None, pfx=None, category=None):
-        self.add_plugin_spec(
-            Bunch(module=module_name, workspace=ws_name, category=category,
-                  ptype='local', path=path, klass=klass, pfx=pfx))
-
-    def add_global_plugin(self, module_name, ws_name,
-                          path=None, klass=None, category='Global',
-                          tab_name=None, start_plugin=True, pfx=None):
-        self.add_plugin_spec(
-            Bunch(module=module_name, workspace=ws_name, tab=tab_name,
-                  path=path, klass=klass, category=category,
-                  ptype='global', start=start_plugin, pfx=pfx))
-
 
 def reference_viewer(sys_argv):
     """Create reference viewer from command line."""
