@@ -102,7 +102,7 @@ class Info(GingaPlugin.GlobalPlugin):
         container.add_widget(vbox, stretch=1)
         self.gui_up = True
 
-    def _create_info_window(self):
+    def _create_info_window(self, channel):
         sw = Widgets.ScrollArea()
 
         vbox = Widgets.VBox()
@@ -154,13 +154,16 @@ class Info(GingaPlugin.GlobalPlugin):
         w, b2 = Widgets.build_info(captions)
         b.update(b2)
         b.cut_levels.set_tooltip("Set cut levels manually")
+        loval, hival = channel.fitsimage.get_cut_levels()
         b.auto_levels.set_tooltip("Set cut levels by algorithm")
         b.cut_low.set_tooltip("Set low cut level (press Enter)")
         b.cut_low.set_length(9)
-        b.cut_low_value.set_text('')
+        b.cut_low.set_text(str(loval))
+        b.cut_low_value.set_text(str(loval))
         b.cut_high.set_tooltip("Set high cut level (press Enter)")
         b.cut_high.set_length(9)
-        b.cut_high_value.set_text('')
+        b.cut_high.set_text(str(hival))
+        b.cut_high_value.set_text(str(hival))
 
         combobox = b.cut_new
         index = 0
@@ -198,7 +201,7 @@ class Info(GingaPlugin.GlobalPlugin):
     def add_channel(self, viewer, channel):
         if not self.gui_up:
             return
-        sw, winfo = self._create_info_window()
+        sw, winfo = self._create_info_window(channel)
         chname = channel.name
 
         self.nb.add_widget(sw, title=chname)
