@@ -8,7 +8,8 @@ import sys
 import math
 import numpy as np
 
-interpolation_methods = ['basic']
+from ginga.util.toolbox import PIL_LT_9_1
+
 _use = None
 
 
@@ -22,52 +23,45 @@ def use(pkgname):
         _use = 'pillow'
 
 
+# Python Imaging Library
+from PIL import Image
+if PIL_LT_9_1:
+    pil_resize = dict(nearest=Image.NEAREST,
+                      linear=Image.BILINEAR,
+                      area=Image.HAMMING,
+                      bicubic=Image.BICUBIC,
+                      lanczos=Image.LANCZOS)
+else:
+    pil_resize = dict(nearest=Image.Resampling.NEAREST,
+                      linear=Image.Resampling.BILINEAR,
+                      area=Image.Resampling.HAMMING,
+                      bicubic=Image.Resampling.BICUBIC,
+                      lanczos=Image.Resampling.LANCZOS)
+
+interpolation_methods = sorted(set(['basic'] + list(pil_resize.keys())))
+
 have_opencv = False
 try:
     # optional opencv package speeds up certain operations, especially
     # rotation
     import cv2
-    cv2_resize = {
-        'nearest': cv2.INTER_NEAREST,
-        'linear': cv2.INTER_LINEAR,
-        'area': cv2.INTER_AREA,
-        'bicubic': cv2.INTER_CUBIC,
-        'lanczos': cv2.INTER_LANCZOS4,
-    }
+    cv2_resize = dict(nearest=cv2.INTER_NEAREST,
+                      linear=cv2.INTER_LINEAR,
+                      area=cv2.INTER_AREA,
+                      bicubic=cv2.INTER_CUBIC,
+                      lanczos=cv2.INTER_LANCZOS4)
     have_opencv = True
 
-    if 'nearest' not in interpolation_methods:
-        interpolation_methods = list(set(['basic'] +
-                                         list(cv2_resize.keys())))
-        interpolation_methods.sort()
-
-except ImportError:
-    pass
-
-have_pillow = False
-try:
-    # do we have Python Imaging Library available?
-    import PIL.Image as PILimage
-    pil_resize = {
-        'nearest': PILimage.NEAREST,
-        'linear': PILimage.BILINEAR,
-        'area': PILimage.HAMMING,
-        'bicubic': PILimage.BICUBIC,
-        'lanczos': PILimage.LANCZOS,
-    }
-    have_pillow = True
-
-    if 'nearest' not in interpolation_methods:
-        interpolation_methods = list(set(['basic'] +
-                                         list(pil_resize.keys())))
-        interpolation_methods.sort()
+    interpolation_methods = sorted(set(['basic'] + list(cv2_resize.keys())))
 
 except ImportError:
     pass
 
 # For testing
 #have_opencv = False
-#have_pillow = False
+
+_dtype_uint8 = np.dtype(np.uint8)
+_dtype_uint16 = np.dtype(np.uint16)
 
 
 def get_center(data_np):
@@ -135,7 +129,7 @@ def rotate_clip(data_np, theta_deg, rotctr_x=None, rotctr_y=None,
     if rotctr_y is None:
         rotctr_y = ht // 2
 
-    if dtype == np.uint8 and have_opencv and _use in (None, 'opencv'):
+    if dtype == _dtype_uint8 and have_opencv and _use in (None, 'opencv'):
         if logger is not None:
             logger.debug("rotating with OpenCv")
         # opencv is fastest
@@ -153,10 +147,10 @@ def rotate_clip(data_np, theta_deg, rotctr_x=None, rotctr_y=None,
             out[:, :, ...] = newdata
             newdata = out
 
-    elif dtype == np.uint8 and have_pillow and _use in (None, 'pillow'):
+    elif dtype == _dtype_uint8 and _use in (None, 'pillow'):
         if logger is not None:
             logger.debug("rotating with pillow")
-        img = PILimage.fromarray(data_np)
+        img = Image.fromarray(data_np)
         img_rot = img.rotate(theta_deg, resample=False, expand=False,
                              center=(rotctr_x, rotctr_y))
         newdata = np.array(img_rot, dtype=data_np.dtype)
@@ -380,7 +374,7 @@ def get_scaled_cutout_wdht(data_np, x1, y1, x2, y2, new_wd, new_ht,
         method = cv2_resize[interpolation]
 
         cutout = data_np[y1:y2 + 1, x1:x2 + 1]
-        if cutout.dtype not in (np.uint8, np.uint16):
+        if cutout.dtype not in (_dtype_uint8, _dtype_uint16):
             # special hack for OpenCv resize on certain numpy array types
             cutout = cutout.astype(np.float64)
 
@@ -391,13 +385,13 @@ def get_scaled_cutout_wdht(data_np, x1, y1, x2, y2, new_wd, new_ht,
         ht, wd = newdata.shape[:2]
         scale_x, scale_y = float(wd) / old_wd, float(ht) / old_ht
 
-    elif data_np.dtype == np.uint8 and have_pillow and _use in (None, 'pillow'):
+    elif data_np.dtype == _dtype_uint8 and _use in (None, 'pillow'):
         if logger is not None:
             logger.info("resizing with pillow")
         if interpolation == 'basic':
             interpolation = 'nearest'
         method = pil_resize[interpolation]
-        img = PILimage.fromarray(data_np[y1:y2 + 1, x1:x2 + 1])
+        img = Image.fromarray(data_np[y1:y2 + 1, x1:x2 + 1])
         img_siz = img.resize((new_wd, new_ht), resample=method)
         newdata = np.array(img_siz, dtype=dtype)
 
@@ -476,7 +470,7 @@ def get_scaled_cutout_basic(data_np, x1, y1, x2, y2, scale_x, scale_y,
         x1, y1, x2, y2 = int(x1), int(y1), int(x2), int(y2)
         cutout = data_np[y1:y2 + 1, x1:x2 + 1]
 
-        if cutout.dtype not in (np.uint8, np.uint16):
+        if cutout.dtype not in (_dtype_uint8, _dtype_uint16):
             # special hack for OpenCv resize on certain numpy array types
             cutout = cutout.astype(np.float64)
         newdata = cv2.resize(cutout, None,
@@ -487,13 +481,13 @@ def get_scaled_cutout_basic(data_np, x1, y1, x2, y2, scale_x, scale_y,
         ht, wd = newdata.shape[:2]
         scale_x, scale_y = float(wd) / old_wd, float(ht) / old_ht
 
-    elif data_np.dtype == np.uint8 and have_pillow and _use in (None, 'pillow'):
+    elif data_np.dtype == _dtype_uint8 and _use in (None, 'pillow'):
         if logger is not None:
             logger.info("resizing with pillow")
         if interpolation == 'basic':
             interpolation = 'nearest'
         method = pil_resize[interpolation]
-        img = PILimage.fromarray(data_np[y1:y2 + 1, x1:x2 + 1])
+        img = Image.fromarray(data_np[y1:y2 + 1, x1:x2 + 1])
         old_wd, old_ht = max(x2 - x1 + 1, 1), max(y2 - y1 + 1, 1)
         new_wd, new_ht = int(scale_x * old_wd), int(scale_y * old_ht)
         img_siz = img.resize((new_wd, new_ht), resample=method)
@@ -630,8 +624,8 @@ def overlay_image_2d_pil(dstarr, pos, srcarr, dst_order='RGBA',
 
     if dst_order != src_order:
         srcarr = reorder_image(dst_order, srcarr, src_order)
-    img_dst = PILimage.fromarray(dstarr)
-    img_src = PILimage.fromarray(srcarr)
+    img_dst = Image.fromarray(dstarr)
+    img_src = Image.fromarray(srcarr)
 
     mask = img_src
     if 'A' not in src_order:
@@ -748,10 +742,9 @@ def overlay_image_2d(dstarr, pos, srcarr, dst_order='RGBA',
                      src_order='RGBA',
                      alpha=1.0, copy=False, fill=False, flipy=False):
     # NOTE: not tested yet thoroughly enough to use
-    # if have_pillow:
-    #     return overlay_image_2d_pil(dstarr, pos, srcarr, dst_order=dst_order,
-    #                                 src_order=src_order, alpha=alpha,
-    #                                 copy=copy, fill=fill, flipy=flipy)
+    # return overlay_image_2d_pil(dstarr, pos, srcarr, dst_order=dst_order,
+    #                             src_order=src_order, alpha=alpha,
+    #                             copy=copy, fill=fill, flipy=flipy)
 
     return overlay_image_2d_np(dstarr, pos, srcarr, dst_order=dst_order,
                                src_order=src_order, alpha=alpha,
@@ -964,7 +957,7 @@ def fill_array(dstarr, order, r, g, b, a):
     bgval = dict(A=int(maxv * a), R=int(maxv * r), G=int(maxv * g),
                  B=int(maxv * b))
     bgtup = tuple([bgval[order[i]] for i in range(len(order))])
-    if dtype == np.uint8 and len(bgtup) == 4:
+    if dtype == _dtype_uint8 and len(bgtup) == 4:
         # optimiztion
         bgtup = np.array(bgtup, dtype=dtype).view(np.uint32)[0]
         dstarr = dstarr.view(np.uint32)
@@ -984,7 +977,7 @@ def make_filled_array(shp, dtype, order, r, g, b, a):
     bgval = dict(A=int(maxv * a), R=int(maxv * r), G=int(maxv * g),
                  B=int(maxv * b))
     bgtup = tuple([bgval[order[i]] for i in range(len(order))])
-    if dtype == np.uint8 and len(bgtup) == 4:
+    if dtype == _dtype_uint8 and len(bgtup) == 4:
         # optimization when dealing with 32-bit RGBA arrays
         fill_val = np.array(bgtup, dtype=dtype).view(np.uint32)
         rgba = np.zeros(shp, dtype=dtype)
@@ -994,9 +987,48 @@ def make_filled_array(shp, dtype, order, r, g, b, a):
     return np.full(shp, bgtup, dtype=dtype)
 
 
+def remove_alpha(arr):
+    """Takes an array and removes an alpha layer from it if it has one.
+
+    Parameters
+    ----------
+    arr : ndarray
+        The input array
+
+    Returns
+    -------
+    new_arr, alpha_arr : both ndarray
+        The input array with the alpha layer removed, and the alpha array
+        None is returned for the alpha array if there was none.
+    """
+    if len(arr.shape) == 2:
+        return arr, None
+
+    if arr.shape[2] in (2, 4):
+        alpha = arr[..., -1]
+        arr = arr[..., 0:-1]
+        return arr, alpha
+
+    return arr, None
+
+
 def add_alpha(arr, alpha=None):
     """Takes an array and adds an alpha layer to it if it doesn't already
-    exist."""
+    exist.
+
+    Parameters
+    ----------
+    arr : ndarray
+        The input array
+
+    alpha : int, float, ndarray or None (optional)
+        A single value or array of values for the alpha layer to be added
+
+    Returns
+    -------
+    new_arr : ndarray
+        The input array with the alpha layer added.
+    """
     if len(arr.shape) == 2:
         arr = arr[..., np.newaxis]
 
@@ -1018,6 +1050,31 @@ def get_minmax_dtype(dtype):
     return info.min, info.max
 
 
+def array_convert(arr_np, to_dtype):
+    """Convert an array from one datatype to another, preserving relative value.
+
+    Parameters
+    ----------
+    arr_np : ndarray
+        A numpy array of data
+
+    to_dtype : numpy dtype (e.g. np.dtype(np.uint16))
+        the ndarray data type to convert to
+
+    Returns
+    -------
+    res_np : ndarray
+       The converted array
+    """
+    if arr_np.dtype == to_dtype:
+        # we are already in the desired datatype--no action
+        return arr_np
+    mn_f, mx_f = get_minmax_dtype(arr_np.dtype)
+    mn_t, mx_t = get_minmax_dtype(to_dtype)
+    arr_np = (arr_np / mx_f * mx_t).astype(to_dtype)
+    return arr_np
+
+
 def check_native_byteorder(data_np):
     dt = str(data_np.dtype)
 
