@@ -9,14 +9,12 @@ import numpy as np
 import matplotlib as mpl
 from matplotlib.figure import Figure
 
-from ginga.util import iqcalc
+from ginga.util import iqcalc as _iqcalc  # Prevent namespace confusion below
 from ginga.misc import Callback, Bunch
 
 # fix issue of negative numbers rendering incorrectly with default font
 mpl.rcParams['axes.unicode_minus'] = False
 
-MPL_GE_2_0 = mpl.__version__[0] not in ('0', '1')
-
 
 class Plot(Callback.Callbacks):
 
@@ -47,7 +45,8 @@ class Plot(Callback.Callbacks):
         self.can = Bunch.Bunch(zoom=False, pan=False)
 
         # For callbacks
-        for name in ['draw-canvas', 'limits-set']:
+        for name in ['draw-canvas', 'limits-set', 'motion',
+                     'button-press', 'key-press', 'scroll']:
             self.enable_callback(name)
 
     def get_figure(self):
@@ -84,16 +83,14 @@ class Plot(Callback.Callbacks):
     def set_bg(self, color, ax=None):
         if ax is None:
             ax = self.ax
-        if MPL_GE_2_0:
-            ax.set_facecolor(color)
-        else:
-            ax.set_axis_bgcolor(color)
+        ax.set_facecolor(color)
 
     def clear(self):
         self.logger.debug('clearing canvas...')
         self.ax.cla()
         self.xdata = []
         self.ydata = []
+        self.draw()
 
     def draw(self):
         self.fig.canvas.draw()
@@ -101,7 +98,7 @@ class Plot(Callback.Callbacks):
         self.make_callback('draw-canvas')
 
     def plot(self, xarr, yarr, xtitle=None, ytitle=None, title=None,
-             rtitle=None, **kwdargs):
+             rtitle=None, show_legend=False, **kwdargs):
 
         if self.ax is None:
             self.add_axis()
@@ -127,6 +124,9 @@ class Plot(Callback.Callbacks):
         for lbl in lbls:
             lbl.set(rotation=45, horizontalalignment='right')
 
+        if show_legend:
+            self.ax.legend()
+
         self.draw()
         return lines
 
@@ -144,16 +144,43 @@ class Plot(Callback.Callbacks):
 
     def connect_ui(self):
         canvas = self.fig.canvas
+        if canvas is None:
+            raise ValueError("matplotlib canvas is not yet created")
         connect = canvas.mpl_connect
-        # This one is not ready for prime time...
-        # connect("motion_notify_event", self.plot_motion_notify)
-        connect("button_press_event", self.plot_button_press)
-        connect("scroll_event", self.plot_scroll)
+        connect("motion_notify_event", self._plot_motion_notify)
+        connect("button_press_event", self._plot_button_press)
+        connect("scroll_event", self._plot_scroll)
+        connect("key_press_event", self._plot_key_press)
 
-    def enable(self, **kwargs):
-        self.can.update(kwargs)
+    def enable(self, pan=False, zoom=False):
+        """If `pan` is True, enable interactive panning in the plot by a
+        middle click.  If `zoom` is True , enable interactive zooming in
+        the plot by scrolling.
+        """
+        self.can.update(dict(pan=pan, zoom=zoom))
+        if pan or zoom:
+            self.connect_ui()
+            if pan:
+                self.add_callback('button-press', self.plot_do_pan)
+            if zoom:
+                self.add_callback('scroll', self.plot_do_zoom)
 
-    def plot_scroll(self, event):
+    def _plot_scroll(self, event):
+        self.make_callback('scroll', event)
+
+    def _plot_button_press(self, event):
+        self.make_callback('button-press', event)
+
+    def _plot_motion_notify(self, event):
+        self.make_callback('motion', event)
+
+    def _plot_key_press(self, event):
+        self.make_callback('key-press', event)
+
+    def plot_do_zoom(self, cb_obj, event):
+        """Can be set as the callback function for the 'scroll'
+        event to zoom the plot.
+        """
         if not self.can.zoom:
             return
         # Matplotlib only gives us the number of steps of the scroll,
@@ -187,24 +214,17 @@ class Plot(Callback.Callbacks):
         height *= self.fig.dpi
         return (width, height)
 
-    def plot_button_press(self, event):
-        if event.button == 1:
-            self.plot_x, self.plot_y = event.xdata, event.ydata
-
-        elif event.button == 2:
+    def plot_do_pan(self, cb_obj, event):
+        """Can be set as the callback function for the 'button-press'
+        event to pan the plot with middle-click.
+        """
+        if event.button == 2:
             if not self.can.pan:
                 return
             self.pan_plot(event.xdata, event.ydata)
 
         return True
 
-    def plot_motion_notify(self, event):
-        if event.button == 1:
-            xdelta = self.plot_x - event.xdata
-            ydelta = self.plot_y - event.ydata
-            pan_x, pan_y = self.plot_x + xdelta, self.plot_y + ydelta
-            self.pan_plot(pan_x, pan_y)
-
     def pan_plot(self, xnew, ynew):
 
         x1, x2 = self.ax.get_xlim()
@@ -302,10 +322,7 @@ class ContourPlot(Plot):
         ##     self.cbar.remove()
 
         self.ax.cla()
-        if MPL_GE_2_0:
-            self.ax.set_facecolor('#303030')
-        else:
-            self.ax.set_axis_bgcolor('#303030')
+        self.ax.set_facecolor('#303030')
 
         try:
             im = self.ax.imshow(data, interpolation=self.interpolation,
@@ -397,8 +414,8 @@ class RadialPlot(Plot):
 
             yerror = 0   # for now, no error bars
             self.ax.errorbar(r, v, yerr=yerror, marker='s', ls='none',
-                             mfc='none', mec='blue')
-            self.ax.plot(x_curve, y_curve, '-', color='green', lw=2)
+                             mfc='none', mec='#7570b3')
+            self.ax.plot(x_curve, y_curve, '-', color='#1b9e77', lw=2)
 
             self.draw()
 
@@ -412,7 +429,7 @@ class FWHMPlot(Plot):
     def __init__(self, *args, **kwargs):
         super(FWHMPlot, self).__init__(*args, **kwargs)
 
-        self.iqcalc = iqcalc.IQCalc(self.logger)
+        self.iqcalc = _iqcalc.IQCalc(self.logger)
 
     def _plot_fwhm_axis(self, arr, iqcalc, skybg, color1, color2, color3,
                         fwhm_method='gaussian'):
@@ -427,7 +444,7 @@ class FWHMPlot(Plot):
         self.logger.debug("Y=%s" % (str(Y)))
         self.ax.plot(X, Y, color=color1, marker='.')
 
-        res = iqcalc.calc_fwhm(arr, method_name=fwhm_method)
+        res = iqcalc.calc_fwhm(arr, medv=skybg, method_name=fwhm_method)
         fwhm, mu = res.fwhm, res.mu
 
         # Make a little smoother fitted curve by plotting intermediate
@@ -461,18 +478,18 @@ class FWHMPlot(Plot):
             if cutout_data is None:
                 cutout_data, x1, y1, x2, y2 = image.cutout_radius(x, y, radius)
 
-            skybg = np.median(cutout_data)
+            skybg = np.ma.median(cutout_data)
             self.logger.debug("cutting x=%d y=%d r=%d med=%f" % (
                 x, y, radius, skybg))
 
             self.logger.debug("xarr=%s" % (str(xarr)))
             fwhm_x = self._plot_fwhm_axis(xarr, iqcalc, skybg,
-                                          'blue', 'blue', 'skyblue',
+                                          '#7570b3', '#7570b3', 'purple',
                                           fwhm_method=fwhm_method)
 
             self.logger.debug("yarr=%s" % (str(yarr)))
             fwhm_y = self._plot_fwhm_axis(yarr, iqcalc, skybg,
-                                          'green', 'green', 'seagreen',
+                                          '#1b9e77', '#1b9e77', 'seagreen',
                                           fwhm_method=fwhm_method)
 
             falg = fwhm_method
@@ -487,6 +504,119 @@ class FWHMPlot(Plot):
             self.logger.error("Error making fwhm plot: %s" % (
                 str(e)))
 
+    def plot_fwhm_data(self, x, y, radius, arr_data,
+                       iqcalc=None, fwhm_method='gaussian'):
+
+        x, y, radius = int(round(x)), int(round(y)), int(round(radius))
+
+        if iqcalc is None:
+            iqcalc = self.iqcalc
+
+        x0, y0, xarr, yarr = iqcalc.cut_cross(x, y, radius, arr_data)
+
+        self.ax.cla()
+
+        self.set_titles(ytitle='Brightness', xtitle='Pixels', title='FWHM')
+        self.ax.grid(True)
+
+        # Make a FWHM plot
+        try:
+            # get median value from the cutout area
+            skybg = np.ma.median(arr_data)
+            self.logger.debug("cutting x=%d y=%d r=%d med=%f" % (
+                x, y, radius, skybg))
+
+            self.logger.debug("xarr=%s" % (str(xarr)))
+            fwhm_x = self._plot_fwhm_axis(xarr, iqcalc, skybg,
+                                          '#7570b3', '#7570b3', 'purple',
+                                          fwhm_method=fwhm_method)
+
+            self.logger.debug("yarr=%s" % (str(yarr)))
+            fwhm_y = self._plot_fwhm_axis(yarr, iqcalc, skybg,
+                                          '#1b9e77', '#1b9e77', 'seagreen',
+                                          fwhm_method=fwhm_method)
+
+            falg = fwhm_method
+            self.ax.legend(('data x', '%s x' % falg, 'data y', '%s y' % falg),
+                           loc='upper right', shadow=False, fancybox=False,
+                           prop={'size': 8}, labelspacing=0.2)
+            self.set_titles(title="FWHM X: %.2f  Y: %.2f" % (fwhm_x, fwhm_y))
+
+            self.draw()
+
+        except Exception as e:
+            self.logger.error("Error making fwhm plot: {}".format(e))
+
+
+class EEPlot(Plot):
+    """Class to handle plotting of encircled and ensquared energy (EE) values."""
+
+    def plot_ee(self, encircled_energy_function=None,
+                ensquared_energy_function=None, sampling_radius=None,
+                total_radius=None):
+        """
+        Parameters
+        ----------
+        encircled_energy_function, ensquared_energy_function : obj or `None`
+            Interpolation function from ``scipy.interpolate.interp1d`` for
+            encircled and ensquared energy (EE) values, respectively.
+            If not given, will skip plotting but at least one needs to be given.
+
+        sampling_radius : float or `None`
+            Show radius for sampling of EE, if desired.
+
+        total_radius : float or `None`
+            Show radius where EE is expected to be 1, if desired.
+
+        """
+        if (encircled_energy_function is None and
+                ensquared_energy_function is None):
+            raise ValueError('At least one EE function must be provided')
+
+        self.ax.cla()
+        self.ax.grid(True)
+
+        x_max = 0
+        title = ''
+        d = {}
+
+        if encircled_energy_function:
+            d['Encircled Energy'] = {'func': encircled_energy_function,
+                                     'color': '#7570b3',
+                                     'marker': 's',
+                                     'title_pfx': 'EE(circ)'}
+        if ensquared_energy_function:
+            d['Ensquared Energy'] = {'func': ensquared_energy_function,
+                                     'color': '#1b9e77',
+                                     'marker': 'x',
+                                     'title_pfx': 'EE(sq)'}
+
+        for key, val in d.items():
+            func = val['func']
+            color = val['color']
+            x = func.x
+            y = func.y
+            x_max = max(x.max(), x_max)
+            self.ax.plot(x, y, color=color, marker=val['marker'], mfc='none',
+                         mec=color, label=key)
+            if total_radius and not title:
+                self.ax.axvline(total_radius, color='k', ls='--')
+            if sampling_radius:
+                if title:
+                    title += ', '
+                else:
+                    self.ax.axvline(sampling_radius, color='k', ls='--')
+                ys = func(sampling_radius)
+                title += f"{val['title_pfx']}={ys:.3f}"
+                self.ax.plot(sampling_radius, ys, marker='o', ls='none',
+                             mfc=color, mec=color, label=None)
+
+        self.set_titles(title=title, xtitle='Radius [pixels]', ytitle='EE')
+        self.ax.set_xlim(-0.1, x_max)
+        self.ax.legend(loc='lower right', shadow=False, fancybox=False,
+                       prop={'size': 8}, labelspacing=0.2)
+        self.draw()
+
 
 class SurfacePlot(Plot):
 
@@ -511,12 +641,7 @@ class SurfacePlot(Plot):
             from mpl_toolkits.mplot3d import Axes3D  # noqa
             from matplotlib.ticker import LinearLocator, FormatStrFormatter
 
-            if MPL_GE_2_0:
-                kwargs = {'facecolor': '#808080'}
-            else:
-                kwargs = {'axisbg': '#808080'}
-
-            self.ax = self.fig.gca(projection='3d', **kwargs)
+            self.ax = self.fig.gca(projection='3d', facecolor='#808080')
 
             self.set_titles(ytitle='Y', xtitle='X',
                             title='Surface Plot')
